@@ -55,7 +55,7 @@ import re
 import operator
 
 __all__ = ['get', 'get_all']
-__version__ = '1.4'
+__version__ = '1.5'
 
 
 # Make it work both in python 2.x and 3.x
@@ -193,9 +193,7 @@ class SliceToken(Token):
         self.step = int(slice_step) if slice_step is not None else None
 
     def parse(self, tokens, data):
-        for item in data[self.start:self.end:self.step]:
-            for value in Token.apply(list(tokens), item):
-                yield value
+        return Token.apply(tokens, data[self.start:self.end:self.step])
 
 
 @Tokenizer.token
@@ -382,11 +380,13 @@ def get_all(jpath, data):
     >>> get_all('a..b', {'a': {'b': 3, 'c': {'b': 4}}})
     [3, 4]
     >>> get_all('[1:]', [1, 2, 3])
-    [2, 3]
+    [[2, 3]]
     >>> get_all('[:-1]', [1, 2, 3])
-    [1, 2]
+    [[1, 2]]
     >>> get_all('[::2]', [1, 2, 3, 4])
-    [1, 3]
+    [[1, 3]]
+    >>> get_all('[::2][0]', [[1, 2], [3, 4], [5, 6]])
+    [[1, 2]]
     >>> get_all('(x=1).y', [{'x':1, 'y':2}, {'x':0, 'y':3}, {'x':1, 'y':4}])
     [2, 4]
     >>> get_all('(x>0).y', [{'x':1, 'y':2}, {'x':0, 'y':3}, {'x':1, 'y':4}])
